# QuickStart

## Use QuickStart to simplify the operation in terminal!

| 命令 | 含义 |
| :--- | :--- |
| `qs -u [url] ` | open url using default browser |
| `qs -a [app/(file...)]` | open app or open file by app(for MacOS X) |
| `qs -f [file...]` | open file by default app |
| `qs -trans [words]` | translate the content of `[words]` or the content in clipboard |
| `qs -time` | view current time |
| `qs -ftp` | start a simple ftp server |
| `qs -top` | cpu and memory monitor |
| `qs -weather [address]` | check weather (of address) |
| `qs -dl [urls/""]` | download file from url(in clipboard) |
| `qs -mktar [path]` | create gzipped archive for path(dir/file) |
| `qs -untar [path]` | extract path.tar.* |
| `qs -mkzip [path]` | make a zip for path(dir/file) |
| `qs -unzip [path]` | unzip path.zip |
| `qs -upload` | upload your pypi library |
| `qs -upgrade` | update qs |
| `qs -pyuninstaller [name]` | remove files that pyinstaller create |

(By the way, if you are the one of China University Of Petroleum(Beijing), run `qs -i` to login school network)

## Some tools for Windows user to normally use qs
- almost have installed automatically by system on Linux/MacOS X
  
  [tar](http://gnuwin32.sourceforge.net/packages/gtar.htm)
  
  [zip](http://gnuwin32.sourceforge.net/packages/zip.htm)
  
  [unzip](http://gnuwin32.sourceforge.net/packages/unzip.htm)
